# embypy
python wrapper for the emby rest api
[![Latest Version](https://img.shields.io/pypi/v/EmbyPy.svg)](https://pypi.python.org/pypi/EmbyPy)
[![Documentation](https://media.readthedocs.org/static/projects/badges/passing.svg)](http://embypy.readthedocs.io/en/latest/)
[![Build Status](https://travis-ci.org/andy29485/embypy.svg?branch=master)](https://travis-ci.org/andy29485/embypy)

## Installing
Installation should be done through the `pip` command:
```
pip install -U embypy
```

It is also possible to install via the `setup.py` file:
```
python setup.py install
```

## Documentation
Documentation is availble at [Read the Docs](http://embypy.readthedocs.io/en/latest/).

## Usage
To use you will need an [Emby](https://emby.media/) server and
an api key generated by that server.

